@@ -31,40 +31,37 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL,conso
 	junto <- subset(data.frame(y, trt), is.na(y) == FALSE)
 	Mean<-mean(junto[,1])
 	CV<-sqrt(MSerror)*100/Mean	
+	medians<-tapply.stat(junto[,1],junto[,2],stat="median")
+    for(i in c(1,5,2:4)) {
+    x <- tapply.stat(junto[,1],junto[,2],function(x)quantile(x)[i])
+    medians<-cbind(medians,x[,2])
+    }
+    medians<-medians[,3:7]
+    names(medians)<-c("Min","Max","Q25","Q50","Q75")
 	means <- tapply.stat(junto[,1],junto[,2],stat="mean") # change
 	sds <-   tapply.stat(junto[,1],junto[,2],stat="sd") #change
 	nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
-	mi<-tapply.stat(junto[,1],junto[,2],stat="min") # change
-	ma<-tapply.stat(junto[,1],junto[,2],stat="max") # change
-	means<-data.frame(means,std=sds[,2],r=nn[,2],Min=mi[,2],Max=ma[,2])
+	means<-data.frame(means,std=sds[,2],r=nn[,2],medians)
 	names(means)[1:2]<-c(name.t,name.y)
 #   row.names(means)<-means[,1]
 	ntr<-nrow(means)
 	Fprob <- qf(1-alpha,ntr-1, DFerror)
 	Tprob <- sqrt(Fprob * (ntr - 1))
-	nr<- 1/mean(1/nn[,2])
+	nr<-unique(nn[, 2])
 	if(console){
 	cat("\nStudy:", main)
 	cat("\n\nScheffe Test for",name.y,"\n")
 	cat("\nMean Square Error  :",MSerror,"\n\n")
 	cat(paste(name.t,",",sep="")," means\n\n")
-	print(data.frame(row.names = means[,1], means[,-1]))
+	print(data.frame(row.names = means[,1], means[,2:6]))
 	cat("\nAlpha:",alpha,"; DF Error:",DFerror,"\n")
 	cat("Critical Value of F:", Fprob,"\n")
 	}
 	scheffe <- Tprob*sqrt(2*MSerror/nr)
-	if (length(unique(nn[,2]))!=1) {
-		if(console)cat("\nHarmonic Mean of Cell Sizes ", nr )
-	}
-	if (group) {
-		if(console){cat("\nMinimum Significant Difference:",scheffe,"\n")
-		cat("\nMeans with the same letter are not significantly different.")
-		cat("\n\nGroups, Treatments and means\n")}
-		groups <- order.group(means[,1], means[,2], means[,4], MSerror, Tprob,means[,3], parameter=1,console=console)
-		comparison=NULL
-		groups <- data.frame(groups[,1:3])
-	}
-	else {
+	statistics<-data.frame(MSerror=MSerror,Df=DFerror, F=Fprob,Mean=Mean,CV=CV)
+	if ( group & length(nr) == 1 & console) cat("\nMinimum Significant Difference:",scheffe,"\n")
+if ( group & length(nr) != 1 & console) cat("\nGroups according to probability of means differences and alpha level(",alpha,")\n")
+if ( length(nr) == 1) statistics<-data.frame(statistics,Scheffe=Tprob,CriticalDifference=scheffe)
 		comb <-utils::combn(ntr,2)
 		nn<-ncol(comb)
 		dif<-rep(0,nn)
@@ -75,10 +72,7 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL,conso
 		for (k in 1:nn) {
 			i<-comb[1,k]
 			j<-comb[2,k]
-#if (means[i, 2] < means[j, 2]){
-#comb[1, k]<-j
-#comb[2, k]<-i
-#}
+
 			dif[k]<-means[i,2]-means[j,2]
 			sdtdif<-sqrt(MSerror * (1/means[i,4] + 1/means[j,4]))
 			pvalue[k]<- round(1-pf(abs(dif[k])^2/((ntr-1)*sdtdif^2),ntr-1,DFerror),4)
@@ -91,22 +85,42 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL,conso
 			else  if (pvalue[k] <= 0.05) sig[k]<-"*"
 			else  if (pvalue[k] <= 0.1) sig[k]<-"."
 		}
+		if(!group){
 		tr.i <- means[comb[1, ],1]
 		tr.j <- means[comb[2, ],1]
 		comparison<-data.frame("Difference" = dif, pvalue=pvalue,sig,LCL,UCL)
 		rownames(comparison)<-paste(tr.i,tr.j,sep=" - ")
-		if(console){cat("\nComparison between treatments means\n\n")
+        if(console){cat("\nComparison between treatments means\n\n")
 		print(comparison)}
 		groups=NULL
-#		output<-data.frame(trt= means[,1],means= means[,2],M="",N=means[,4],std.err=means[,3])
+    }
+	if (group) {
+	  if(console) {
+	  cat("\nMeans with the same letter are not significantly different.\n\n")
+ 	  }
+	  comparison=NULL
+	  # Matriz de probabilidades
+	  Q<-matrix(1,ncol=ntr,nrow=ntr)
+	  p<-pvalue
+	  k<-0
+	  for(i in 1:(ntr-1)){
+	    for(j in (i+1):ntr){
+	      k<-k+1
+	      Q[i,j]<-p[k]
+	      Q[j,i]<-p[k]
+	    }
+	  }
+	  groups <- orderPvalue(means[, 1], means[, 2],alpha, Q,console)
+      names(groups)[1]<-name.y
+      if(console) print(groups)
 	}
-	statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror,CriticalDifference=scheffe)
-	parameters<-data.frame(Df=DFerror,ntr = ntr, F=Fprob,Scheffe=Tprob,alpha=alpha,test="Scheffe",name.t=name.t)
+	parameters<-data.frame(test="Scheffe",name.t=name.t,ntr = ntr,alpha=alpha)
 	rownames(parameters)<-" "
 	rownames(statistics)<-" "
 	rownames(means)<-means[,1]
 	means<-means[,-1]
 	output<-list(statistics=statistics,parameters=parameters, 
 			means=means,comparison=comparison,groups=groups)
+	class(output)<-"group"
 	invisible(output)
 }
